package
Version:
v0.0.0-...-443d657
Opens a new window with list of versions in this module.
Published: Jul 18, 2016
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type EventRecord struct {
Id bson.ObjectId `bson:"_id,omitempty"`
Type string `bson:"type"`
Timestamp int64 `bson:"created_at"`
Event interface{} `bson:"event"`
}
The EventRecord containing the event and metadata about it
Source Files
¶
Click to show internal directories.
Click to hide internal directories.